@@ -337,12 +337,15 @@ class YandexParser(object):
 
     @classmethod
     def is_yandex(cls, content):
-        return '<a class="logo__link" href="//www.yandex.' in content \
+        return \
+            '<meta property="og:site_name" content="Яндекс">' in content \
+            or '<a class="logo__link" href="//www.yandex.' in content \
             or u'<title>Яндекс' in content \
             or u'href="https://www.yandex.ru" title="Яндекс"' in content \
             or '<a class="logo logo_type_link' in content \
             or cls.IS_YANDEX_PATTERN in content
 
+
     def get_clean_html(self):
         return YandexSerpCleaner.clean(self.content)
 
